ConfigOperation

Enum ConfigOperation 

pub enum ConfigOperation {
Show 15 variants SetToolchain(String), RemoveToolchain, DefaultFeatures(bool), AddFeature(String), RemoveFeature(String), SetBuildProfile(Cow<'static, str>), SetInstallPrereleases(bool), SetEnforceLock(bool), SetRespectBinaries(bool), SetTargetVersion(VersionReq), RemoveTargetVersion, SetEnvironment(String, String), ClearEnvironment(String), InheritEnvironment(String), ResetConfig,
}
A single operation to be executed upon configuration of a package.

Variants



SetToolchain(String)

Set the toolchain to use to compile the package.



RemoveToolchain

Use the default toolchain to use to compile the package.



DefaultFeatures(bool)

Whether to compile the package with the default features.



AddFeature(String)

Compile the package with the specified feature.



RemoveFeature(String)

Remove the feature from the list of features to compile with.



SetBuildProfile(Cow<'static, str>)

Set build profile (dev/release/~/.cargo/config.toml [profile.gaming]/&c.)



SetInstallPrereleases(bool)

Set allowing to install prereleases to the specified value.



SetEnforceLock(bool)

Set enforcing Cargo.lock to the specified value.



SetRespectBinaries(bool)

Set installing only the pre-set binaries.



SetTargetVersion(VersionReq)

Constrain the installed to the specified one.



RemoveTargetVersion

Always install latest package version.



SetEnvironment(String, String)

Set environment variable to given value for cargo install.



ClearEnvironment(String)

Remove environment variable for cargo install.



InheritEnvironment(String)

Remove configuration for an environment variable.



ResetConfig

Reset configuration to default values.